<?php

namespace Drp\SimpleCms\Test\Unit;

use Drp\SimpleCms\Test\Support\Fakes\TestContent;
use Drp\SimpleCms\Test\TestCase;
use Drp\SimpleCms\Validator;
use Illuminate\Http\RedirectResponse;
use Illuminate\Validation\ValidationException;

/**
 * Class ValidatorTest
 * @package Tests
 */
class ValidatorTest extends TestCase
{
    /**
     * @test
     */
    public function it_returns_true_when_a_content_is_valid()
    {
        $content = new TestContent(['title' => 'present'], ['title' => 'required']);
        $validator = $this->app->make(Validator::class);
        $validator->validateContent($content);
    }

    /**
     * @test
     */
    public function it_throws_a_validation_exception_when_the_validation_fails()
    {
        try {
            $content = new TestContent(['title' => null], ['title' => 'required']);
            $validator = $this->app->make(Validator::class);
            $validator->validateContent($content);
        } catch (ValidationException $exception) {
            $errors = $exception->validator->getMessageBag();
            $this->assertTrue($errors->has('title'));
            $this->assertInstanceOf(RedirectResponse::class, $exception->getResponse());
            $this->assertHasOldInput('title');
            return;
        }

        $this->fail('Field was not validated as required!');
    }


}
